<?php
/**
 * Plugin Name: Elementor Sonaar Addons
 * Description: This plugin will boost Elementor page builder with the Sonaar's widgets. Sonaar.io theme is required.
 * Plugin URI:  https://sonaar.io/
 * Version:     2.3.7
 * Author:      Sonaar Music
 * Author URI:  https://sonaar.io/
 * Text Domain: elementor-sonaar
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Main Sonaar Elementor Class
 *
 * The main class that initiates and runs the plugin.
 *
 * @since 1.0.0
 */
final class Elementor_Sonaar {

/**
	 * Plugin Version
	 *
	 * @since 1.0.0
	 *
	 * @var string The plugin version.
	 */
	const SONAARELEMENTOR_VERSION = '2.3.7';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum PHP version required to run the plugin.
	*/
	const MINIMUM_PHP_VERSION = '5.6';

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var Elementor_Sonaar The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 * @static
	 *
	 * @return Elementor_Sonaar An instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct() {	
		add_action( 'init', [ $this, 'i18n' ] );
		add_action( 'plugins_loaded', [ $this, 'init' ] );
	}

	/**
	 * Load Textdomain
	 *
	 * Load plugin localization files.
	 *
	 * Fired by `init` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function i18n() {
		load_plugin_textdomain( 'elementor-sonaar', FALSE, basename( dirname( __FILE__ ) ) . '/lang/' );
	}
    /**
     * Check if a plugin is active
     *
     * @since 3.0.0
     */
    public function is_plugin_active($plugin){
        include_once ABSPATH . 'wp-admin/includes/plugin.php';
        return is_plugin_active($plugin);
	}

	/**
     * Check if a plugin is installed
     *
     * @since v3.0.0
     */
    public function is_plugin_installed($basename){
        if (!function_exists('get_plugins')) {
            include_once ABSPATH . '/wp-admin/includes/plugin.php';
        }
        $installed_plugins = get_plugins();
        return isset($installed_plugins[$basename]);
	}
	
	/**
     * Check if elementor plugin is activated
     *
     * @since v1.0.0
     */
    public function admin_notice_missing_main_plugin(){
        if (!current_user_can('activate_plugins')) {
            return;
        }

        $elementor = 'elementor/elementor.php';

        if ($this->is_plugin_installed($elementor)) {
            $activation_url = wp_nonce_url('plugins.php?action=activate&amp;plugin=' . $elementor . '&amp;plugin_status=all&amp;paged=1&amp;s', 'activate-plugin_' . $elementor);

            $message = sprintf(__('%1$sElementor for Sonaar%2$s requires %1$sElementor%2$s plugin to be active. Please activate Elementor to continue.', 'elementor-sonaar'), "<strong>", "</strong>");

            $button_text = __('Activate Elementor', 'essential-addons-for-elementor-lite');
        } else {
            $activation_url = wp_nonce_url(self_admin_url('update.php?action=install-plugin&plugin=elementor'), 'install-plugin_elementor');

            $message = sprintf(__('%1$sElementor for Sonaar%2$s requires %1$sElementor%2$s plugin to be installed and activated. Please install Elementor to continue.', 'elementor-sonaar'), '<strong>', '</strong>');
            $button_text = __('Install Elementor', 'elementor-sonaar');
        }

        $button = '<p><a href="' . $activation_url . '" class="button-primary">' . $button_text . '</a></p>';
        printf('<div class="error"><p>%1$s</p>%2$s</div>', __($message), $button);
	}
	
	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by 'plugins_loaded' action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init() {

		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}
		// Check if Elementor installed and activated
		if (!function_exists('curl_version')){
			add_action( 'admin_notices', [ $this, 'admin_notice_curl_disabled' ] );
		}

		// Check for required Elementor version			
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
		}
		add_action( 'init', [ $this, 'sr_init_extensions' ] ); // load CF options
		// Editor Styles
		add_action( 'elementor/editor/after_enqueue_styles', [ $this, 'srelementor_register_styles_editor' ] );
		add_action( 'elementor/editor/before_enqueue_scripts',[ $this, 'srelementor_register_scripts_editor' ] );

		// Register/Enqueue Scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'srelementor_register_scripts_front' ] );
		add_action( 'elementor/frontend/after_register_styles', [ $this, 'srelementor_register_styles' ] );
		add_action( 'wp_enqueue_scripts', function() { 
			wp_enqueue_style( 'sr-addons-elementor' ); 
		} );

		add_action( 'elementor/frontend/before_enqueue_scripts', function() { 
			wp_enqueue_script( 'sr-scripts-elementor' ); 
		} );
	}

	/*
		* Init Extensions
		*
		* @since 1.4.8				
		*
		* @access public
	*/	
	public function sr_init_extensions() {
		
		// Include extension classes
		include_once plugin_dir_path( __FILE__ ) . '/includes/queries.php';
		include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-sitelogo.php';
		include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-menu.php';
		include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-offcanvas.php';
		include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-textgradient.php';
		include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-dualheading.php';
		include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-sticky.php';

		if(class_exists('Iron_sonaar')){
			
			include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-essgrid.php';
			include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-videolist.php';
			include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-promobox.php';
			include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-events.php';
			include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-bandsintown.php';
			include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-parallaxgrid.php';
			if(!class_exists('Sonaar_Music')){ // if Sonaar MP3 plugin is activated
				include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-podcast-player.php';
				include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-podcast-archive.php';
				include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-music-player.php';
				include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-buttonplayer.php';
			}
			include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-beatstars_player.php';
			if ( function_exists( 'wpcf7' )) {
				include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-wpcf7.php';
			}
			if ( class_exists('RevSliderFront')){
				include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-revslider.php';
			}
			if (function_exists('curl_version')){
				require_once( __DIR__ . '/includes/mailchimp-subscription.php' );
				include_once plugin_dir_path( __FILE__ ) . '/widgets/sr-mailchimp.php';
			}
		}
	}

	/*
		* Init styles for Elementor Editor
		*
		* Include css files and register them
		*
		* @since 1.0.0				
		*
		* @access public
	*/
	public function srelementor_register_styles_editor() {
		wp_enqueue_style( 'sonaar-elementor-editor', plugins_url( 'assets/css/elementor-editor.css', __FILE__ ), [ 'elementor-editor' ], self::SONAARELEMENTOR_VERSION );
	}
		/*
		* Init script for Elementor Editor
		*
		* Include css files and register them
		*
		* @since 1.0.0				
		*
		* @access public
	*/
	public function srelementor_register_scripts_editor() {
		wp_register_script( 'sr-scripts-elementor', plugins_url( 'assets/js/sonaar-addons-elementor.min.js', __FILE__ ), [ 'jquery', 'underscore' ],self::SONAARELEMENTOR_VERSION, true );
	}
	/*
		* Init styles
		*
		* Include css files and register them
		*
		* @since 1.0.0				
		*
		* @access public
	*/
	public function srelementor_register_styles() {
		wp_register_style('sr-addons-elementor', plugins_url( 'assets/css/sonaar-addons-elementor.css', __FILE__ ), [ 'elementor-frontend' ], self::SONAARELEMENTOR_VERSION );
	}
	/*
		* Init Scripts
		*
		* Include js files and register them
		*
		* @since 1.0.0				
		*
		* @access public
	*/
	public function srelementor_register_scripts_front() {
		wp_register_script( 'sr-scripts-elementor', plugins_url( 'assets/js/sonaar-addons-elementor.min.js', __FILE__ ), [ 'jquery', 'underscore' ],self::SONAARELEMENTOR_VERSION, true );


		$sonaar_mailchimp_settings = array(
		'ajax_url' => admin_url('admin-ajax.php'),
		);

		wp_localize_script( 'sr-scripts-elementor', 'sonaarMailchimp', $sonaar_mailchimp_settings );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function admin_notice_curl_disabled() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( 'The Mailchimp widget included in "%1$s" plugin has been disabled because cURL library is not enabled on your server. If you want to use the Mailchimp widget, check with your hosting provider to enable cURL library.', 'elementor-sonaar' ),
			'<strong>' . esc_html__( 'Elementor for Sonaar', 'elementor-sonaar' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'elementor-sonaar' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
	}
}
Elementor_Sonaar::instance();